if not getActivatedMods():contains("RandomSoundEvents") then return; end

--- Load Utils and RandomSoundEventsAPI
local Utils = require 'RandomSoundEvents/Utils';
local RandomSoundEventsAPI = require 'RandomSoundEvents/Classes/RandomSoundEventsAPI';

local modName = "RandomSoundEvents_Stalker";

-- CAN PLAY
-- Server Function to validate if the sound event can play
local function canPlay(player, x, y)
     return not Utils.IsDusk() -- Wont play during dusk
end


-- ON PLAY
-- Client Function triggered when the sound event start.
local function onPlay(soundName, soundRange, x, y)
    Utils.PlayerWorldSoundAt(x, y, 0, soundRange, nil);

    if SandboxVars.RandomSoundEvents_Stalker.disableFear then return; end
    Utils.ForEachLocalPlayer(function(player)

        if not player:isDead() and not player:isGodMod() then
            if Utils.IsInRange(soundRange, x, y, player:getX(), player:getY()) then
                local stats = player:getStats();
                local panic = stats:getPanic();
                local stress = stats:getStress();

                if player:HasTrait("Brave") then
                    stats:setPanic(panic + 5);
                    stats:setStress(stress + 0.5);
                else
                    if not SandboxVars.RandomSoundEvents_Stalker.disableWakingUp and player:isAsleep() then
                        player:setAsleep(false);
                        player:setAsleepTime(0.0);
                        UIManager.FadeIn(player:getPlayerNum(), 1);
                    end
                    stats:setPanic(panic + 10);
                    stats:setStress(stress + 0.05);
                end
            end
        end

    end);
end

-- ON UPDATE
-- Client Function triggered every tick during the sound event.
local function onUpdate(ticks, soundName, soundRange, x, y)
    if SandboxVars.RandomSoundEvents_Stalker.disableFear then return; end

    Utils.ForEachLocalPlayer(function(player)

        if not player:isDead() and not player:isGodMod() then

            if Utils.IsInRange(soundRange, x, y, player:getX(), player:getY()) then
                local gameTimeMultiplier = getGameTime():getMultiplier();
    
                -- Stress the un-brave player
                if not player:HasTrait("Brave") then
                    local stats = player:getStats();
                    local panic = stats:getPanic();
                    local stress = stats:getStress();

                    stats:setPanic(panic + 0.01 * gameTimeMultiplier);
                    stats:setStress(stress + 0.0002 * gameTimeMultiplier);
                end
            end

        end

    end);
end

-- ON COMPLETED
-- Client Function triggered when the sound event is completed.
local function onCompleted(soundName, soundRange, x, y)

end

--- Infected Sound
--- { SoundName, Range, canPlayFunction, onPlayFunction, onUpdateFunction, onCompletedFunction },
RandomSoundEventsAPI.Add(modName, "Stalker", {
    { "dog", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "dog1", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "dog2", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "dog3", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "crow1", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "crow2", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "crow3", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "howling_1", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "howling_2", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "iron_moaning", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "krik1", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "krik2", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "krik3", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "krik4", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "krik5", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "krik6", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "krik7", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "krik8", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "krik9", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "moan", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "moan1", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "moan2", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "moan3", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "moan4", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "moan5", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "moan6", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "pdog", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "pdog1", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "pdog2", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "pdog3", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "shooting_1", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "shooting_2", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "shooting_3", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "shooting_4", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "shooting_5", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "shooting_6", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "shooting_7", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "shooting_8", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "shooting_9", 60, canPlay, onPlay, onUpdate, onCompleted },
    { "shooting_10", 60, canPlay, onPlay, onUpdate, onCompleted }
});